emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/sisu-mode e9a90ec 3/8: sisu-mode.el: Add .sisu to auto-


From: Stefan Monnier
Subject: [elpa] externals/sisu-mode e9a90ec 3/8: sisu-mode.el: Add .sisu to auto-mode-alist using autoload cookie.
Date: Sun, 29 Nov 2020 00:18:10 -0500 (EST)

branch: externals/sisu-mode
commit e9a90ecdae702aa409de1d6fdb520f8748ac5c29
Author: Chong Yidong <cyd@stupidchicken.com>
Commit: Chong Yidong <cyd@stupidchicken.com>

    sisu-mode.el: Add .sisu to auto-mode-alist using autoload cookie.
    Minor doc fixes.
---
 sisu-mode.el | 31 ++++++++++++++++---------------
 1 file changed, 16 insertions(+), 15 deletions(-)

diff --git a/sisu-mode.el b/sisu-mode.el
index 0b14a7c..ce85990 100644
--- a/sisu-mode.el
+++ b/sisu-mode.el
@@ -1,4 +1,4 @@
 ;;; sisu-mode.el --- a major-mode for highlighting a hierarchy structured text.
 
 ;; Copyright (C) 2011  Free Software Foundation, Inc.
 
@@ -16,7 +16,7 @@
 ;; it under the terms of the GNU General Public License as published by
 ;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
-;; 
+;;
 ;; This program is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -31,20 +31,17 @@
 
 ;;; Commentary:
 
-;;
-;; To enter sisu-mode automatically, add (autoload 'sisu-mode "sisu-mode")
-;; to your .emacs file and change the first line of your sisu file to:
+;; SiSU (http://www.sisudoc.org/) is a document structuring and
+;; publishing framework.  This package provides an Emacs major mode
+;; for SiSU markup.
+
+;; When this package is installed, files ending in ".sisu" are
+;; automatically associated with sisu-mode.  If a file doesn't have a
+;; .sisu extension, add a first line:
 ;; # -*- Sisu -*-
-;; if it doesn't have a .sisu extension.
-;;
-;; To handle .sisu files, e.g., 'filename.sisu', add something like
-;; (add-to-list 'auto-mode-alist '("\\.sisu$" . sisu-mode))
-;; to your .emacs file
 
-;;
-;; The documentation for the "Structure Of The Hierarchy Text" can be found in
-;; the sisustring for the sisu-mode function.
-;;
+;; The documentation for the "Structure Of The Hierarchy Text" can be
+;; found in the sisustring for the sisu-mode function.
 
 ;;; Code:
 
@@ -340,7 +337,9 @@
 
 ;;;###autoload
 (define-derived-mode sisu-mode text-mode "SiSU"
-  "Major mode for editing SiSU files."
+  "Major mode for editing SiSU files.
+SiSU (http://www.sisudoc.org/) is a document structuring and
+publishing framework.  This major mode handles SiSU markup."
   (modify-syntax-entry ?\'  ".")
   ;(flyspell-mode nil)
 
@@ -363,6 +362,8 @@
     ))
   (run-hooks 'sisu-mode-hook))
 
+;;;###autoload (add-to-list 'auto-mode-alist '("\\.sisu\\'" . sisu-mode))
+
 (provide 'sisu-mode)
 
 ;;}}}
@@ -1,4 +1,4 @@
-;;; sisu-mode.el --- a major-mode for highlighting a hierarchy structured text.
+;;; sisu-mode.el --- Major mode for SiSU markup text
 
 ;; Copyright (C) 2011  Free Software Foundation, Inc.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]